View source: R/cbind_gen_tibble.R
| cbind.gen_tbl | R Documentation |
A cbind() method to merge gen_tibble objects with data.frames and normal
tibbles. Whilst this works, it is not ideal as it does not check the order of
the tables, and we suggest that you use dplyr::left_join() instead. Note
that cbind will not combine two gen_tibbles (i.e. it will NOT combine
markers for the same individuals)
## S3 method for class 'gen_tbl'
cbind(..., deparse.level = 1)
... |
a gen_tibble and a data.frame or tibble |
deparse.level |
an integer controlling the construction of column names.
See |
a gen_tibble
example_gt <- load_example_gt("gen_tbl")
# Create a dataframe to combine with the gen_tibble
df <- data.frame(region = c("A", "A", "B", "B", "A", "B", "B"))
# Combine the gen_tibble with the dataframe
example_gt <- cbind(example_gt, df)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.