View source: R/gt_update_backingfile.R
| gt_update_backingfile | R Documentation |
This functions forces a re-write of the file backing matrix to match the
gen_tibble. Individuals and loci are subsetted and reordered according to
the current state of the gen_tibble. A .gt, .bk and .rds file will be
created.
gt_update_backingfile(
.x,
backingfile = NULL,
chunk_size = NULL,
rm_unsorted_dist = TRUE,
quiet = FALSE
)
.x |
a |
backingfile |
the path, including the file name without extension, for backing files used to store the data (they will be given a .bk and .rds automatically). If left to NULL (the default), the file name will be based on the name f the current backing file. |
chunk_size |
the number of loci to process at once |
rm_unsorted_dist |
boolean to set |
quiet |
boolean to suppress information about the files |
This function does not check whether the positions of your genetic loci are
sorted. To check this, and update the file backing matrix, use
gt_order_loci(). Tests for this function are in
test_gt_order_loci.R
a gen_tibble with updated .gt, .bk, and .rds files
(i.e. a new File Backed Matrix)
example_gt <- load_example_gt("gen_tbl")
# Here, new backingfiles are created, but without using `<-` the object
# loaded in the R session is not updated
gt_update_backingfile(example_gt)
# Make sure to use `<-` to update the file names associated with the
# gen_tibble object loaded in the R session
example_gt <- example_gt %>% gt_update_backingfile()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.