- .x
a gen_tibble object
- .col
the column to be used when a tibble (or grouped tibble is passed
directly to the function). This defaults to "genotypes" and can only take
that value. There is no need for the user to set it, but it is included to
resolve certain tidyselect operations.
- ...
currently not used.
- S
A vector of loci statistics which express the importance of each SNP
(the more important is the SNP, the greater should be the corresponding
statistic).
For example, if S follows the standard normal
distribution, and "important" means significantly different from 0, you
must use abs(S) instead.
If not specified, MAFs are computed and used.
- thr_r2
Threshold over the squared correlation between two SNPs.
Default is 0.2.
- size
For one SNP, window size around this SNP to compute correlations.
Default is 100 / thr_r2 for clumping (0.2 -> 500; 0.1 -> 1000; 0.5 ->
200). If use_positions = FALSE, this is a window in number of SNPs,
otherwise it is a window in kb (genetic distance). Ideally, use positions,
as they provide a more sensible approach.
- exclude
Vector of SNP indices to exclude anyway. For example, can be
used to exclude long-range LD regions (see Price2008). Another use can be
for thresholding with respect to p-values associated with S.
- use_positions
boolean, if TRUE (the default), size is in kb, if
FALSE size is the number of SNPs.
- n_cores
number of cores to be used
- return_id
boolean on whether the id of SNPs to keep should be
returned. It defaults to FALSE, which returns a vector of booleans (TRUE or
FALSE)