Learn R Programming

tidypopgen (version 0.4.3)

loci_names: Get the names of loci in a gen_tibble

Description

Extract the loci names from a gen_tibble (or directly from its genotype column).

Usage

loci_names(.x, .col = "genotypes", ...)

# S3 method for tbl_df loci_names(.x, .col = "genotypes", ...)

# S3 method for vctrs_bigSNP loci_names(.x, .col = "genotypes", ...)

Value

a character vector of names

Arguments

.x

a vector of class vctrs_bigSNP (usually the genotype column of a gen_tibble object), or a gen_tibble.

.col

the column to be used when a tibble (or grouped tibble is passed directly to the function). This defaults to "genotypes" and can only take that value. There is no need for the user to set it, but it is included to resolve certain tidyselect operations.

...

currently unused.

Examples

Run this code
example_gt <- load_example_gt("gen_tbl")
example_gt %>% loci_names()

Run the code above in your browser using DataLab