Use the loci table to define which loci are transitions
Usage
loci_transitions(.x, .col = "genotypes", ...)
# S3 method for tbl_df
loci_transitions(.x, .col = "genotypes", ...)
# S3 method for vctrs_bigSNP
loci_transitions(.x, .col = "genotypes", ...)
Value
a logical vector defining which loci are transitions
Arguments
.x
a vector of class vctrs_bigSNP (usually the genotype column of
a gen_tibble object),
or a gen_tibble.
.col
the column to be used when a tibble (or grouped tibble is passed
directly to the function). This defaults to "genotypes" and can only take
that value. There is no need for the user to set it, but it is included to
resolve certain tidyselect operations.