Learn R Programming

tidypopgen (version 0.4.3)

loci_transversions: Find transversions

Description

Use the loci table to define which loci are transversions

Usage

loci_transversions(.x, .col = "genotypes", ...)

# S3 method for tbl_df loci_transversions(.x, .col = "genotypes", ...)

# S3 method for vctrs_bigSNP loci_transversions(.x, .col = "genotypes", ...)

Value

a logical vector defining which loci are transversions

Arguments

.x

a vector of class vctrs_bigSNP (usually the genotype column of a gen_tibble object), or a gen_tibble.

.col

the column to be used when a tibble (or grouped tibble is passed directly to the function). This defaults to "genotypes" and can only take that value. There is no need for the user to set it, but it is included to resolve certain tidyselect operations.

...

other arguments passed to specific methods.

Examples

Run this code
example_gt <- load_example_gt("gen_tbl")
example_gt %>% loci_transversions()

Run the code above in your browser using DataLab