Learn R Programming

tidypopgen (version 0.4.3)

show_genotypes: Show the genotypes of a gen_tibble

Description

Extract the genotypes (as a matrix) from a gen_tibble.

Usage

show_genotypes(.x, indiv_indices = NULL, loci_indices = NULL, ...)

# S3 method for tbl_df show_genotypes(.x, indiv_indices = NULL, loci_indices = NULL, ...)

# S3 method for vctrs_bigSNP show_genotypes(.x, indiv_indices = NULL, loci_indices = NULL, ...)

Value

a matrix of counts of the alternative alleles (see show_loci()) to extract information on the alleles for those loci from a gen_tibble.

Arguments

.x

a vector of class vctrs_bigSNP (usually the genotype column of a gen_tibble object), or a gen_tibble.

indiv_indices

indices of individuals

loci_indices

indices of loci

...

currently unused.

Examples

Run this code
example_gt <- load_example_gt("gen_tbl")

example_gt %>% show_genotypes()

Run the code above in your browser using DataLab