Skip to contents

Provides support for the mathematical predicate functions is.finite(), is.infinite(), and is.nan() on vctrs_bigSNP vectors.

Usage

vec_math.vctrs_bigSNP(.fn, .x, ...)

Arguments

.fn

Name of the mathematical function being dispatched.

.x

A vctrs_bigSNP vector.

...

Unused additional arguments.

Value

A logical vector for is.finite(), is.infinite(), and is.nan().

Details

These methods are primarily required for compatibility with RStudio's object inspector and other tooling that may call mathematical predicates on custom vctrs classes.

All other Math-group generics are deliberately unsupported and will raise an error.