chromosome: the chromosome for the window
start: the starting locus of the window
end: the ending locus of the window
tajimas_d: the Tajima's D for the population
if data are grouped, either:
a data frame as above with the following columns:
chromosome: the chromosome for the window
start: the starting locus of the window
end: the ending locus of the window
n_loci: the number of loci in the window
group: the Tajima's D for the group for the given window (there will be
as many of these columns as groups in the gen_tibble, and they will be
named by the grouping levels)
a tidy tibble with the following columns:
chromosome: the chromosome for the window
start: the starting locus of the window
end: the ending locus of the window
n_loci: the number of loci in the window
group: the name of the group
stat: the Tajima's D for the given group at the given window
or a list of data frames, one per group, with the following columns:
chromosome: the chromosome for the window
start: the starting locus of the window
end: the ending locus of the window
stat: the Tajima's D for the given window
n_loci: the number of loci in the window