Learn R Programming

tidypopgen (version 0.4.3)

cbind.gen_tbl: Combine a gen_tibble to a data.frame or tibble by column

Description

A cbind() method to merge gen_tibble objects with data.frames and normal tibbles. Whilst this works, it is not ideal as it does not check the order of the tables, and we suggest that you use dplyr::left_join() instead. Note that cbind will not combine two gen_tibbles (i.e. it will NOT combine markers for the same individuals)

Usage

# S3 method for gen_tbl
cbind(..., deparse.level = 1)

Value

a gen_tibble

Arguments

...

a gen_tibble and a data.frame or tibble

deparse.level

an integer controlling the construction of column names. See cbind for details.

Examples

Run this code
example_gt <- load_example_gt("gen_tbl")

# Create a dataframe to combine with the gen_tibble
df <- data.frame(region = c("A", "A", "B", "B", "A", "B", "B"))

# Combine the gen_tibble with the dataframe
example_gt <- cbind(example_gt, df)

Run the code above in your browser using DataLab