Convert a gentibble to a .geno file for sNMF from the LEA package
Source: R/gt_as_geno_lea.R
gt_as_geno_lea.RdThis function writes a .geno file from a gen_tibble. Unless a file path
is given, a file with suffix .geno is written in the same location as the
.rds and .bk files that underpin the gen_tibble.
Arguments
Details
NOTE that we currently read all the data into memory to write the file, so this function is not suitable for very large datasets.
Note
the .geno format only supports haploid or diploid data, so this
function only works on diploid (or pseudohaploid) gen_tibble objects.
Pseudohaploid data is simply treated as regular diploid genotype counts
(dosage 0/2), the same convention used by other tools (e.g. PLINK).
Examples
example_gt <- load_example_gt("gen_tbl")
# Write a geno file
gt_as_geno_lea(example_gt, file = paste0(tempfile(), "_example.geno"))
#> [1] "/tmp/RtmpqbnViX/file29bc7a7bfae7_example.geno"