Learn R Programming

tidypopgen (version 0.4.3)

gt_get_file_names: Get the names of files storing the genotypes of a gen_tibble

Description

A function to return the names of the files used to store data in a gen_tibble. Specifically, this returns the .rds file storing the big

Usage

gt_get_file_names(x)

Value

a character vector with the names and paths of the two files

Arguments

x

a gen_tibble

Examples

Run this code
example_gt <- load_example_gt("gen_tbl")

# To retrieve the names of and paths to the .bk and .rds files use:
gt_get_file_names(example_gt)

Run the code above in your browser using DataLab