powered by
gen_tibble
A function to return the names of the files used to store data in a gen_tibble. Specifically, this returns the .rds file storing the big
gt_get_file_names(x)
a character vector with the names and paths of the two files
a gen_tibble
example_gt <- load_example_gt("gen_tbl") # To retrieve the names of and paths to the .bk and .rds files use: gt_get_file_names(example_gt)
Run the code above in your browser using DataLab