gt_uses_imputed: Checks if a gen_tibble uses imputed data
Description
This function checks if a dataset uses imputed data. Note that it is possible
to have a dataset that has been imputed but it is currently not using
imputation.
Usage
gt_uses_imputed(x)
Value
boolean TRUE or FALSE depending on whether the dataset is using the
imputed values