powered by
gen_tibble
Extract and set the information on loci from a gen_tibble.
show_loci(.x, ...)# S3 method for tbl_df show_loci(.x, ...)# S3 method for vctrs_bigSNP show_loci(.x, ...)show_loci(.x) <- value# S3 method for tbl_df show_loci(.x) <- value# S3 method for vctrs_bigSNP show_loci(.x) <- value
# S3 method for tbl_df show_loci(.x, ...)
# S3 method for vctrs_bigSNP show_loci(.x, ...)
show_loci(.x) <- value
# S3 method for tbl_df show_loci(.x) <- value
# S3 method for vctrs_bigSNP show_loci(.x) <- value
a tibble::tibble of information (see gen_tibble for details on compulsory columns that will always be present)
tibble::tibble
a vector of class vctrs_bigSNP (usually the genotype column of a gen_tibble object), or a gen_tibble.
vctrs_bigSNP
genotype
currently unused.
a data.frame or tibble of loci information to replace the current one.
example_gt <- load_example_gt("gen_tbl") example_gt %>% show_loci()
Run the code above in your browser using DataLab